@@ -20,7 +20,7 @@ import numpy as np
 from datetime import datetime
 from dfm_python import DFM, DFMDataModule, DFMTrainer
 from dfm_python.config import DFMConfig, SeriesConfig, DEFAULT_BLOCK_NAME
-from dfm_python.utils.time import TimeIndex, parse_timestamp
+from dfm_python.utils.time import TimeIndex
 
 # sktime imports for preprocessing
 from sktime.transformations.compose import TransformerPipeline
@@ -67,7 +67,7 @@ selected_cols = [
 # Filter to only columns that exist in the data
 selected_cols = [col for col in selected_cols if col in df.columns]
 
-# Filter data
+# Filter data (include date column for time index)
 df_processed = df[selected_cols + ["date"]].copy()
 print(f"   Selected {len(selected_cols)} series (including target)")
 print(f"   Series: {selected_cols[:5]}...")
@@ -76,10 +76,6 @@ print(f"   Series: {selected_cols[:5]}...")
 df_processed["date"] = pd.to_datetime(df_processed["date"])
 df_processed = df_processed.sort_values("date")
 
-# Remove date column for processing
-date_col = df_processed["date"].copy()
-df_processed = df_processed.drop(columns=["date"])
-
 # Remove rows with all NaN
 df_processed = df_processed.dropna(how='all')
 
@@ -88,7 +84,6 @@ df_processed = df_processed.dropna(how='all')
 max_periods = 100
 if len(df_processed) > max_periods:
     df_processed = df_processed.iloc[-max_periods:]
-    date_col = date_col.iloc[-max_periods:]
     print(f"   Using last {max_periods} periods for faster execution")
 
 print(f"   Data shape after cleaning: {df_processed.shape}")
@@ -114,8 +109,19 @@ if target_col in df_processed.columns:
     df_processed[target_col] = target_diff
     print(f"   Applied difference transformation to {target_col}")
 
+# Note: date column will be removed by DataModule when time_index_column='date' is used
+# For preprocessing, we need to temporarily remove it to avoid issues with datetime columns
+# Store date column separately for reference (though DataModule will extract it)
+if 'date' in df_processed.columns:
+    # Temporarily remove date column for preprocessing (DataModule will handle it)
+    df_for_preprocessing = df_processed.drop(columns=['date'])
+else:
+    df_for_preprocessing = df_processed
+
 # Create simplified preprocessing pipeline: Imputation → Scaling
 # (Transformations already applied manually above)
+# This pipeline will be fitted and used to preprocess data
+# Then passed to DataModule for statistics extraction (Mx/Wx)
 preprocessing_pipeline = TransformerPipeline(
     steps=[
         ('impute_ffill', Imputer(method="ffill")),  # Forward fill missing values
@@ -136,9 +142,19 @@ print("   Pipeline: Imputer(ffill) → Imputer(bfill) → StandardScaler")
 print(f"   Transformations: {target_col} uses difference (chg), others use linear")
 print("   Applying preprocessing pipeline...")
 
-# Fit preprocessing pipeline on training data once
-fitted_pipeline = preprocessing_pipeline.clone().fit(df_processed)
-df_preprocessed = fitted_pipeline.transform(df_processed)
+# Fit preprocessing pipeline on training data once (without date column)
+fitted_pipeline = preprocessing_pipeline.clone().fit(df_for_preprocessing)
+df_preprocessed = fitted_pipeline.transform(df_for_preprocessing)
+
+# Ensure output is DataFrame
+if isinstance(df_preprocessed, np.ndarray):
+    df_preprocessed = pd.DataFrame(df_preprocessed, columns=df_for_preprocessing.columns, index=df_for_preprocessing.index)
+elif not isinstance(df_preprocessed, pd.DataFrame):
+    df_preprocessed = pd.DataFrame(df_preprocessed)
+
+# Add date column back for DataModule to extract (if it exists)
+if 'date' in df_processed.columns:
+    df_preprocessed['date'] = df_processed['date'].values
 
 # Ensure output is DataFrame
 if isinstance(df_preprocessed, np.ndarray):
@@ -150,9 +166,10 @@ missing_after = df_preprocessed.isnull().sum().sum()
 print(f"   Missing values after preprocessing: {missing_after}")
 print(f"   Preprocessed data shape: {df_preprocessed.shape}")
 
-# Verify standardization
-mean_vals = df_preprocessed.mean()
-std_vals = df_preprocessed.std()
+# Verify standardization (exclude date column if present)
+df_for_check = df_preprocessed.drop(columns=['date']) if 'date' in df_preprocessed.columns else df_preprocessed
+mean_vals = df_for_check.mean()
+std_vals = df_for_check.std()
 max_mean = float(mean_vals.abs().max())
 max_std_dev = float((std_vals - 1.0).abs().max())
 print(f"   Standardization check - Max |mean|: {max_mean:.6f} (should be ~0)")
@@ -217,17 +234,16 @@ print(f"   Target series: {target_col}")
 # ============================================================================
 print("\n[Step 4] Creating DataModule...")
 
-# Create time index from date column
-# Align with processed data (after dropping NaN rows)
-valid_dates = date_col.iloc[:len(df_processed)].values
-time_index = TimeIndex([parse_timestamp(str(d)) for d in valid_dates])
-
-# Create DataModule with transformer
+# Create DataModule with preprocessed data
+# Since data is already preprocessed, use preprocessed=True
+# Pipeline is already fitted, so it will only be used for statistics extraction
+# time_index_column='date' will extract time index from DataFrame and remove the column
 data_module = DFMDataModule(
     config=config,
-    data=df_processed.values,
-    time_index=time_index,
-    pipeline=preprocessing_pipeline  # Pass the preprocessing pipeline
+    data=df_processed,  # Pass DataFrame directly (not .values)
+    time_index_column='date',  # Extract time index from 'date' column and exclude it from data
+    pipeline=fitted_pipeline,  # Already fitted pipeline
+    preprocessed=True  # Data is already preprocessed
 )
 data_module.setup()
 
@@ -236,7 +252,8 @@ if hasattr(data_module, 'data_processed') and data_module.data_processed is not
     print(f"   Processed data shape: {data_module.data_processed.shape}")
 else:
     print(f"   Data shape: {df_processed.shape}")
-print(f"   Time range: {time_index[0]} to {time_index[-1]}")
+if data_module.time_index is not None:
+    print(f"   Time range: {data_module.time_index[0]} to {data_module.time_index[-1]}")
 
 # ============================================================================
 # Step 5: Train Model
@@ -263,7 +280,8 @@ X_forecast = None
 Z_forecast = None
 X_forecast_history = None
 Z_forecast_history = None
-scaler = _get_fitted_scaler(fitted_pipeline, df_processed)
+# Use df_for_preprocessing (without date column) for scaler extraction
+scaler = _get_fitted_scaler(fitted_pipeline, df_for_preprocessing)
 
 try:
     # Predict with default horizon
@@ -320,13 +338,13 @@ try:
     X_new_raw = df_processed.iloc[-n_new_periods:].values
     
     # Option 1: Update scaler with new data (fit_transform on update batch)
-    update_pipeline = preprocessing_pipeline.clone().fit(
-        pd.DataFrame(X_new_raw, columns=df_processed.columns, index=df_processed.index[-n_new_periods:])
-    )
-    X_new_std = update_pipeline.transform(
-        pd.DataFrame(X_new_raw, columns=df_processed.columns, index=df_processed.index[-n_new_periods:])
-    )
-    update_scaler = _get_fitted_scaler(update_pipeline, pd.DataFrame(X_new_raw, columns=df_processed.columns))
+    # Remove date column if present
+    X_new_df = pd.DataFrame(X_new_raw, columns=df_processed.columns, index=df_processed.index[-n_new_periods:])
+    X_new_df_for_preprocessing = X_new_df.drop(columns=['date']) if 'date' in X_new_df.columns else X_new_df
+    
+    update_pipeline = preprocessing_pipeline.clone().fit(X_new_df_for_preprocessing)
+    X_new_std = update_pipeline.transform(X_new_df_for_preprocessing)
+    update_scaler = _get_fitted_scaler(update_pipeline, X_new_df_for_preprocessing)
     
     # Handle any NaN values (missing data in new observations)
     X_new_std = np.where(np.isfinite(X_new_std), X_new_std, np.nan)
